Learn R Programming

erma (version 0.4.1)

states_25: metadata on states of 25-state model of chromatin from ChromImpute, and on cell types in the epigenome road map of April 2015

Description

metadata on states of 25-state model of chromatin from ChromImpute

Usage

data("states_25")

Arguments

Format

A data frame with 25 observations on the following 5 variables.
STATENO.
a numeric vector
MNEMONIC
a character vector
DESCRIPTION
a character vector
COLOR.NAME
a character vector, partly non-compliant with R colors
COLOR.CODE
a character vector, RGB numerics, comma-delimited
rgb
a character vector, RGB scores in R atomic format

Details

Some modifications needed to remove registered trademark symbol mistakenly present in 'regulatory' and non-ascii elements of prime notations

Examples

Run this code
data(states_25)
## maybe str(states_25) ; plot(states_25) ...

Run the code above in your browser using DataLab